SRCOD_R

Type Alias SRCOD_R 

pub type SRCOD_R = FieldReader<u32, u32>;
Field SRCOD reader - SRCOD is a 32-bit read-only register used to output the data after sampling rate conversion. The data in the 16-stage output data FIFO is read through SRCOD. When the number of data in the output data FIFO is zero after the start of conversion, the value previously read is read again.

Aliased Type

pub struct SRCOD_R { /* private fields */ }