OCH_R

Type Alias OCH_R 

pub type OCH_R = BitReader<OCH_A>;
Field OCH reader - Output Data Channel Exchange

Aliased Type

pub struct OCH_R { /* private fields */ }

Implementations

Source

impl OCH_R

pub fn variant(&self) -> OCH_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1