pub type OCH_R = BitReader<OCH_A>;
Field OCH reader - Output Data Channel Exchange
OCH
pub struct OCH_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1